
from setuptools import setup, find_packages

setup(
    name='myocr',
    version='0.1.0',
    packages=find_packages(),
    description='A sample myocr package',
    author='Your Name',
    author_email='you@example.com',
    url='https://github.com/yourusername/myocr',
    install_requires=[],
)
